#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dir-traverse
version:              0.2.3.0
visibility:           public
id:                   dir-traverse-0.2.3.0-KElbQ9fzDLF3Holx7cPZUn
key:                  dir-traverse-0.2.3.0-KElbQ9fzDLF3Holx7cPZUn
license:              BSD-3-Clause
copyright:            Copyright: (c) 2019 Vanessa McHale
maintainer:           vamchale@gmail.com
author:               Vanessa McHale
synopsis:             Simple directory traversal library
description:          Simple cross-platform directory traversals in Haskell
category:             System, Directory
abi:                  2f8b353845ae79e1ee9d6ee2408e1909
exposed:              True
exposed-modules:      System.Directory.Recursive
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dir-traverse-0.2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dir-traverse-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dir-traverse-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dir-traverse
hs-libraries:         HSdir-traverse-0.2.3.0-KElbQ9fzDLF3Holx7cPZUn
depends:              base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1
haddock-interfaces:
    /usr/share/doc/haskell-dir-traverse/html/dir-traverse.haddock

haddock-html:         /usr/share/doc/haskell-dir-traverse/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

